Function alternatively

pub fn alternatively<T, E>(
    f1: impl FnOnce() -> Result<T, E>,
    f2: impl FnOnce() -> Result<T, E>,
) -> Result<T, E>
Try two argument-less functions of the same function type to generate T, if both fail, return the error of the second attempt (the first error is lost).